package com.ruoyi.system.service;

import com.ruoyi.system.domain.EpsBusinessScript;

import java.util.List;

/**
 * 业务脚本管理Service接口
 * 
 * @author gyt
 * @date 2025-10-13
 */
public interface IEpsBusinessScriptService 
{
    /**
     * 查询业务脚本管理
     * 
     * @param id 业务脚本管理主键
     * @return 业务脚本管理
     */
    public EpsBusinessScript selectEpsBusinessScriptById(Long id);

    /**
     * 查询业务脚本管理列表
     * 
     * @param epsBusinessScript 业务脚本管理
     * @return 业务脚本管理集合
     */
    public List<EpsBusinessScript> selectEpsBusinessScriptList(EpsBusinessScript epsBusinessScript);

    /**
     * 新增业务脚本管理
     * 
     * @param epsBusinessScript 业务脚本管理
     * @return 结果
     */
    public int insertEpsBusinessScript(EpsBusinessScript epsBusinessScript);

    /**
     * 修改业务脚本管理
     * 
     * @param epsBusinessScript 业务脚本管理
     * @return 结果
     */
    public int updateEpsBusinessScript(EpsBusinessScript epsBusinessScript);

    /**
     * 批量删除业务脚本管理
     * 
     * @param ids 需要删除的业务脚本管理主键集合
     * @return 结果
     */
    public int deleteEpsBusinessScriptByIds(Long[] ids);

    /**
     * 删除业务脚本管理信息
     * 
     * @param id 业务脚本管理主键
     * @return 结果
     */
    public int deleteEpsBusinessScriptById(Long id);

}
